IPython.core.debugger.Pdb is now interruptible
==============================================

A ``KeyboardInterrupt`` will now interrupt IPython's extended debugger, in order to make Jupyter able to interrupt it.
